# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['modkit']
install_requires = \
['varname']

setup_kwargs = {
    'name': 'modkit',
    'version': '0.3.1',
    'description': 'Tweak your modules the way you want',
    'long_description': "# modkit\n\n[![Pypi](https://img.shields.io/pypi/v/modkit?style=flat-square)](https://pypi.org/project/modkit/)\n[![Github](https://img.shields.io/github/tag/pwwang/modkit?style=flat-square)](https://github.com/pwwang/modkit)\n[![PythonVers](https://img.shields.io/pypi/pyversions/modkit?style=flat-square)](https://pypi.org/project/modkit/)\n\nTweak your modules the way you want\n\n## Installation\n```shell\npip install -U modkit\n```\n\n## Usage\n\n`module.py`\n\n```python\nimport modkit\n\na = 1\nd = {}\n\ndef __getattr__(name):\n    # we have this supported with python3.7+\n    # but with modkit, you can do it with python3.6+\n    return name.upper()\n\ndef __getitem__(name):\n    return name.lower()\n\ndef __call__(name):\n    return name * 2\n\nmodkit.install()\n```\n\n```python\nimport module\n\nmodule.a # 1\nmodule.b # B\nmodule.d # {}\nmodule['c'] # C\nmodule('e') # ee\n```\n\n### Baking a module\n\nYou can make a copy of your module with modkit easily.\n\n`module.py`\n\n```python\nfrom modkit import install, bake\n\nd = {}\n\ndef __call__():\n    module2 = bake()\n    return module2\n    # or return bake('module2')\n\ninstall()\n```\n\n```python\nimport module\n\nm2 = module()\nm2\n# <module 'module2' from './module.py' (wrapped by modkit)>\nm2.__name__ # 'module2\nm2.d['a'] = 1\n\nmodule.d == {}\n```\nNote that baking re-execute the original module and generate a new module.\n\n### Submodules\n\nSay we have following structure:\n```\n|- module\n   |- __init__.py\n   |- sub.py\n```\nIf `__getattr__` is defined in `__init__.py`, when we do:\n```python\nfrom module import sub\n# or\n# import module\n# module.sub\n```\n`__getattr__` will first handle this, meaning the `sub` module will not be imported as expected. You have to do it inside `__getattr__`:\n\n`modkit` has a helper function `submodule`, which tries to import the submodule under current one.\n\n```python\nfrom modkit import install, submodule\ndef __getattr__(name):\n    submod = submodule(name)\n    if submod:\n        # submodule imported\n        return submod\n    # other stuff you want to do with name\n    # or raise error\n\ninstall()\n```\n\nThen `from module import sub` or `module.sub` will work as expected.\n\nNote that `submodule` will not raise `ImportError`. If import fails, it will return `None`.\n\nNote that we can also import submodules from a baked module, just like we do for the original module.\n",
    'author': 'pwwang',
    'author_email': 'pwwang@pwwang.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pwwang/modkit',
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
